@@ -12,7 +12,7 @@
 #' by the batsman. A loess line is fitted over the points
 #'
 #' @usage
-#' batsmanRunsVsStrikeRate(df, name= "A Late Cut")
+#' batsmanRunsVsStrikeRate(df, name= "A Late Cut",staticIntv=1)
 #'
 #' @param df
 #' Data frame
@@ -20,6 +20,9 @@
 #' @param name
 #' Name of batsman
 #'
+#' @param staticIntv
+#' Static or interactive -staticIntv =1 (static plot) &  staticIntv =2 (interactive  plot)
+#'
 #' @return None
 #' @references
 #' \url{https://cricsheet.org/}\cr
@@ -47,14 +50,27 @@
 #'
 #' @export
 #'
-batsmanRunsVsStrikeRate <- function(df,name= "A Late Cut"){
+batsmanRunsVsStrikeRate <- function(df,name= "A Late Cut",staticIntv=1){
     batsman = runs = strikeRate = NULL
+    ggplotly=NULL
     b <- select(df,batsman,runs,strikeRate)
 
     plot.title = paste(name,"- Runs vs Strike Rate")
-    ggplot(b) + geom_point(aes(x=runs, y=strikeRate),colour="darkgrey") +
-        geom_smooth(aes(x=runs, y=strikeRate)) +
-        xlab("Strike rate(%)") + ylab("Runs") +
-        ggtitle(bquote(atop(.(plot.title),
-                            atop(italic("Data source:http://cricsheet.org/"),""))))
+    if(staticIntv ==1){ #ggplot2
+        ggplot(b) + geom_point(aes(x=runs, y=strikeRate),colour="darkgrey") +
+            geom_smooth(aes(x=runs, y=strikeRate)) +
+            xlab("Strike rate(%)") + ylab("Runs") +
+            ggtitle(bquote(atop(.(plot.title),
+                                atop(italic("Data source:http://cricsheet.org/"),""))))
+
+   } else { #ggplotly
+
+       g <- ggplot(b) + geom_point(aes(x=runs, y=strikeRate),colour="darkgrey") +
+           geom_smooth(aes(x=runs, y=strikeRate)) +
+           xlab("Strike rate(%)") + ylab("Runs") +
+           ggtitle(plot.title)
+       ggplotly(g)
+
+   }
 }
+
